@@ -18,7 +18,7 @@ LOGGING_CONFIG = {
 
     'formatters': {
         'default_formatter': {
-            'format': '%(asctime)s %(name)-12s %(levelname)-8s %(message)s'
+            'format': '%(asctime)s [%(levelname)s] %(message)s'
         },
     },
 
